<?php namespace EscapeWork\Manager\Controller;

use EscapeWork\Manager\Model\Role;
use App;
use Input;
use Redirect;
use Msg;
use View;

class RoleController extends ManagerController
{

    public function __construct()
    {
        parent::__construct();
        
        $this->role       = App::make('RoleRepository');
        $this->page       = App::make('PageRepository');
        $this->roleAction = App::make('RoleActionRepository');

        $this->enableDefaultFilters('usuarios');
    }

    /**
     * Listing the roles
     */
    public function index()
    {
        $view        = View::make('manager::roles.index');
        $view->roles = $this->role->get();

        return $view;
    }

    /**
     * Form for creating a role
     */
    public function create()
    {
        Msg::setInfo('Inserindo uma nova regra');

        $view              = View::make('manager::roles.form');
        $view->role        = $this->role;
        $view->edit        = false;
        $view->pages       = $this->page->with('actions')->get();
        $view->roleActions = $this->roleAction->getByRole($this->role->id);

        return $view;
    }

    /**
     * Storing a new role
     */
    public function store()
    {
        $fields = Input::all();
        $this->role->fill($fields);

        if (! $this->role->validate()) {
            return Redirect::route('manager.roles.create')
                    ->withInput()
                    ->with('errors', Role::$messages);
        }

        $this->role->save();

        # saving the actions allowed
        $this->roleAction->role_id = $this->role->id;
        $this->roleAction->saveAll(Input::get('action'), Input::get('page'));

        return Redirect::route('manager.roles.index')
                ->with('message', 'A regra <strong>'.$this->role->title.'</strong> foi inserida com sucesso!');
    }

    /**
     * Form for editing a role
     */
    public function edit($id)
    {
        if (! $this->role = $this->role->find($id)) {
            return Redirect::route('manager.roles.index')
                    ->with('error', 'Regra não encontrada');
        }

        Msg::setInfo('Editando a regra <strong>'.$this->role->title.'</strong>');

        $view              = View::make('manager::roles.form');
        $view->role        = $this->role;
        $view->edit        = true;
        $view->pages       = $this->page->with('actions')->get();
        $view->roleActions = $this->roleAction->getByRole($this->role->id);

        return $view;
    }

    /**
     * Updating the role
     */
    public function update($id)
    {
        if (! $this->role = $this->role->find($id)) {
            return Redirect::route('manager.roles.index')
                    ->with('error', 'Regra não encontrada');
        }

        $fields = Input::all();
        $this->role->fill($fields);

        if (! $this->role->validate()) {
            return Redirect::route('manager.roles.edit', $this->role->id)
                    ->withInput()
                    ->with('errors', Role::$messages);
        }

        $this->role->save();

        # saving the actions allowed
        $this->roleAction->role_id = $this->role->id;
        $this->roleAction->deleteByRole($this->role->id);
        $this->roleAction->saveAll(Input::get('action'), Input::get('page'));

        return Redirect::route('manager.roles.index')
                ->with('message', 'A regra <strong>'.$this->role->title.'</strong> foi atualizada com sucesso!');
    }

    /**
     * Destroying the role
     */
    public function destroy($id)
    {
        if (! $this->role = $this->role->find($id)) {
            return Redirect::route('manager.roles.index')
                    ->with('error', 'Regra não encontrada');
        }

        $this->role->delete();

        return Redirect::route('manager.roles.index')
                ->with('message', 'A regra <strong>'.$this->role->title.'</strong> foi excluída com sucesso!');
    }
}