<?php namespace EscapeWork\Manager\Model;

use EscapeWork\LaravelHelpers\Eloquent;
use EscapeWork\Manager\Repository\PageActionRepository;
use Illuminate\Database\Eloquent\Collection;

class PageAction extends Eloquent implements PageActionRepository
{
    
    /**
     * Table
     */
    protected $table = 'manager_page_actions';

    /**
     * Fillable fields
     */
    public $fillable = array(
        'id', 
        'page_id', 
        'title', 
        'type', 
    );

    /**
     * Default actions
     */
    public $defaultActions = array(
        array('type' => 'read', 'title' => 'Listar'), 
        array('type' => 'create', 'title' => 'Inserir'), 
        array('type' => 'update', 'title' => 'Editar'),  
        array('type' => 'destroy', 'title' => 'Excluir'), 
    );

    /**
     * Saving all page actions
     *
     * @param  array $actions
     */
    public function saveAll($titles = array(), $types = array())
    {
        foreach ((array) $titles as $i => $title) {
            $type = $types[$i];
            
            $this->insertNew($this->page_id, $title, $type);
        }
    }

    /**
     * Inserting a new action in the page
     */
    public function insertNew($page_id, $title, $type)
    {
        $pageAction          = new PageAction();
        $pageAction->page_id = $page_id;
        $pageAction->title   = $title;
        $pageAction->type    = $type;
        $pageAction->save();
    }

    /**
     * Deleting all actions 
     */
    public function deleteByPage($page_id)
    {
        $this->where('page_id', '=', $page_id)->delete();
    }

    /**
     * Returning the actions of a determined page
     */
    public function getByPage($page_id)
    {
        return $this->where('page_id', '=', $page_id)->get();
    }

    /**
     * Returning a collection of default actions
     */
    public function getDefaultActions()
    {
        $models = array();
        foreach ($this->defaultActions as $action) {
            $pageAction        = new PageAction();
            $pageAction->title = $action['title'];
            $pageAction->type  = $action['type'];

            $models[] = $pageAction;
        }

        return new Collection($models);
    }

    /**
     * Checking if the actions has changed
     *
     * @param   Illuminate\Database\Eloquent\Collection $pageActions
     * @param   array                                   $types
     * @return  booleam
     */
    public function hasChanged($pageActions, $types)
    {
        $newCount = count($types);
        $oldCount = 0;

        if (count($pageActions) != $newCount) {
            return true;
        }

        foreach ($pageActions as $pageAction) {
            if (in_array($pageAction->type, $types)) {
                $oldCount++;
            }
        }

        return $newCount != $oldCount;
    }

    /**
     * Checking if a actions exists by the page id and the type
     */
    public static function findByPageAndType($page_id, $type)
    {
        return static::where('page_id', '=', $page_id)
                     ->where('type', '=', $type)
                     ->first();
    }
}