<?php 
/**
 * Rotas padrões dos pacotes 
 *
 * @author  Luís Dalmolin <luis@escape.ppg.br>
 */

# ==================================================================
# binds 
# ==================================================================
App::bind('UserRepository', 'EscapeWork\Manager\Model\User');
App::bind('RoleRepository', 'EscapeWork\Manager\Model\Role');
App::bind('RoleActionRepository', 'EscapeWork\Manager\Model\RoleAction');
App::bind('UserRoleRepository', 'EscapeWork\Manager\Model\UserRole');
App::bind('PageRepository', 'EscapeWork\Manager\Model\Page');
App::bind('PageActionRepository', 'EscapeWork\Manager\Model\PageAction');
App::bind('EscapeWork\Manager\Permission', function($app, $parameters)
{
    return new EscapeWork\Manager\Permission($parameters[0], $parameters[1]);
});

Route::bind('user', function($id, $route)
{
    $user = App::make('UserRepository');
    if (! $user = $user->find($id)) {
        App::abort(404);
    }

    return $user;
});

# ==================================================================
# filtro de login do manager 
# ==================================================================
Route::filter('manager.auth', function()
{
    if (Auth::guest()) return Redirect::intended(Config::get('manager::url') .  '/login');
});


Route::group(array('prefix' => Config::get('manager::url')), function()
{
    # ==================================================================
    # login 
    # ==================================================================
    Route::get('login', array('as' => 'manager.login', 'uses' => 'EscapeWork\Manager\Controller\LoginController@index'));
    Route::post('login', 'EscapeWork\Manager\Controller\LoginController@login');
    Route::get('logout', array('as' => 'manager.logout', 'uses' => 'EscapeWork\Manager\Controller\LoginController@logout'));


    # ==================================================================
    # grupo que precisa de autenticação 
    # ==================================================================
    Route::group(array('before' => 'manager.auth'), function()
    {
        # ==================================================================
        # home 
        # ==================================================================
        Route::get('/', array('as' => 'manager.home', function() 
        {
            return View::make(Config::get('manager::templates.home'));
        }));

        # 404 
        App::missing(function($exception)
        {
            return Response::view('manager::errors.404', array(), 404);
        });

        # ==================================================================
        # usuários 
        # ==================================================================
        Route::get('usuarios', array('as' => 'manager.users.index', 'uses' => 'EscapeWork\Manager\Controller\UserController@index'));
        Route::get('usuarios/create', array('as' => 'manager.users.create', 'uses' => 'EscapeWork\Manager\Controller\UserController@create'));
        Route::post('usuarios', array('as' => 'manager.users.store', 'uses' => 'EscapeWork\Manager\Controller\UserController@store'));
        Route::get('usuarios/{id}', array('as' => 'manager.users.show', 'uses' => 'EscapeWork\Manager\Controller\UserController@show'));
        Route::get('usuarios/{id}/edit', array('as' => 'manager.users.edit', 'uses' => 'EscapeWork\Manager\Controller\UserController@edit'));
        Route::put('usuarios/{id}', array('as' => 'manager.users.update', 'uses' => 'EscapeWork\Manager\Controller\UserController@update'));
        Route::delete('usuarios/{id}', array('as' => 'manager.users.destroy', 'uses' => 'EscapeWork\Manager\Controller\UserController@destroy'));

        # ==================================================================
        # roles 
        # ==================================================================
        Route::get('regras', array('as' => 'manager.roles.index', 'uses' => 'EscapeWork\Manager\Controller\RoleController@index'));
        Route::get('regras/create', array('as' => 'manager.roles.create', 'uses' => 'EscapeWork\Manager\Controller\RoleController@create'));
        Route::post('regras', array('as' => 'manager.roles.store', 'uses' => 'EscapeWork\Manager\Controller\RoleController@store'));
        Route::get('regras/{id}/edit', array('as' => 'manager.roles.edit', 'uses' => 'EscapeWork\Manager\Controller\RoleController@edit'));
        Route::put('regras/{id}', array('as' => 'manager.roles.update', 'uses' => 'EscapeWork\Manager\Controller\RoleController@update'));
        Route::delete('regras/{id}', array('as' => 'manager.roles.destroy', 'uses' => 'EscapeWork\Manager\Controller\RoleController@destroy'));

        # ==================================================================
        # pages 
        # ==================================================================
        Route::get('paginas', array('as' => 'manager.pages.index', 'uses' => 'EscapeWork\Manager\Controller\PageController@index'));
        Route::get('paginas/create', array('as' => 'manager.pages.create', 'uses' => 'EscapeWork\Manager\Controller\PageController@create'));
        Route::post('paginas', array('as' => 'manager.pages.store', 'uses' => 'EscapeWork\Manager\Controller\PageController@store'));
        Route::get('paginas/{id}/edit', array('as' => 'manager.pages.edit', 'uses' => 'EscapeWork\Manager\Controller\PageController@edit'));
        Route::put('paginas/{id}', array('as' => 'manager.pages.update', 'uses' => 'EscapeWork\Manager\Controller\PageController@update'));
        Route::delete('paginas/{id}', array('as' => 'manager.pages.destroy', 'uses' => 'EscapeWork\Manager\Controller\PageController@destroy'));
    });
});

# ====================================================================
# UnauthorizedExcpetion
# ====================================================================
App::error(function(EscapeWork\Manager\UnauthorizedExcpetion $exception)
{
    return View::make('manager::unauthorized');
});